@@ -61,18 +61,8 @@ def _calculate_normalized_hash(context_id):
     Calculate a normalized hash of a context id (a fraction between 0 to 1).
     """
     context_id_encoded = context_id.encode("ascii")
-    print(f"context id encoded: {context_id_encoded}")
     # We chose sha224 here to have a different and independent hashing than sha1 which
     # is used on our end for similar purposes.
-    print(f"hashlib.sha224(context_id_encoded).hexdigest() {hashlib.sha224(context_id_encoded).hexdigest()}")
-    print(f"int(hashlib.sha224(context_id_encoded).hexdigest(), base=16) {int(hashlib.sha224(context_id_encoded).hexdigest(), base=16)}")
-    print(f"with mod {(int(hashlib.sha224(context_id_encoded).hexdigest(), base=16)% NORMALIZED_HASH_PRECISION)}")
-
-    ret = (
-        int(hashlib.sha224(context_id_encoded).hexdigest(), base=16)
-        % NORMALIZED_HASH_PRECISION
-    ) / NORMALIZED_HASH_PRECISION
-    print(f"context id: {context_id}, norm hash: {ret}")
     return (
         int(hashlib.sha224(context_id_encoded).hexdigest(), base=16)
         % NORMALIZED_HASH_PRECISION
